@@ -45,6 +45,22 @@ class BaseConfig(Configuration):
         'crispy_forms',
         'tailwind',
         'drf_spectacular',
+        'wagtail.contrib.forms',
+        'wagtail.contrib.redirects',
+        'wagtail.contrib.routable_page',
+        'wagtail.embeds',
+        'wagtail.sites',
+        'wagtail.users',
+        'wagtail.snippets',
+        'wagtail.documents',
+        'wagtail.images',
+        'wagtail.search',
+        'wagtail.admin',
+        'wagtail.contrib.modeladmin',
+        'wagtail',
+        'modelcluster',
+        'taggit',
+        'wagtailcodeblock',
     ]
 
     PROJECT_APPS = [
@@ -66,6 +82,7 @@ class BaseConfig(Configuration):
         'django.contrib.auth.middleware.AuthenticationMiddleware',
         'django.contrib.messages.middleware.MessageMiddleware',
         'django.middleware.clickjacking.XFrameOptionsMiddleware',
+        'wagtail.contrib.redirects.middleware.RedirectMiddleware',
     ]
     DATABASE_URL = values.DatabaseURLValue('postgres://speedpycom:speedpycom@db/speedpycom')  # type: dict
 
@@ -186,14 +203,20 @@ class BaseConfig(Configuration):
             return f'https://{self.STATIC_S3_DOMAIN}/{self.STATIC_S3_PATH}/'
         return f'{self.STATIC_HOST}/static/'
 
-    MEDIA_MODE = values.Value()  # 's3'
+    MEDIA_MODE = values.Value()  # 's3' or 'local'
     MEDIA_S3_ACCESS_KEY_ID = values.Value()
     MEDIA_S3_SECRET_ACCESS_KEY = values.Value()
     MEDIA_S3_BUCKET_NAME = values.Value()
     MEDIA_S3_PATH = values.Value('media')
     MEDIA_S3_CUSTOM_DOMAIN = values.Value()
     MEDIA_HOST = values.Value('')
-    DEFAULT_FILE_STORAGE = 'speedpycom.storages.PublicMediaStorage'
+    MEDIA_ROOT = values.Value('media')
+
+    @property
+    def DEFAULT_FILE_STORAGE(self):
+        if self.MEDIA_MODE == 'local':
+            return 'django.core.files.storage.FileSystemStorage'
+        return 'speedpycom.storages.PublicMediaStorage'
 
     @property
     def MEDIA_S3_DOMAIN(self):
@@ -203,7 +226,10 @@ class BaseConfig(Configuration):
 
     @property
     def MEDIA_URL(self):
-        return f'https://{self.MEDIA_S3_DOMAIN}/{self.MEDIA_S3_PATH}/'
+        if self.MEDIA_MODE == 's3':
+            return f'https://{self.MEDIA_S3_DOMAIN}/{self.MEDIA_S3_PATH}/'
+        else:
+            return f'{self.MEDIA_HOST}/'
 
     DEFAULT_FROM_EMAIL = values.Value()
 
